@@ -120,6 +120,7 @@ class CdrReportGetScheme(BaseModelScheme):
     ingress_rate_effective_date = Str()
     egress_rate_effective_date = Str()
     dnis_fuzzy = Str()
+    anis_fuzzy = Str()
 
     orig_shaken_status = Str()
     orig_shaken_lvl = Str()
@@ -145,7 +146,7 @@ class CdrReportGetScheme(BaseModelScheme):
         model = model.ClientCdr
         fields = ()
         query_fields = ('start_time', 'end_time', 'field', 'tz', 'human_readable', 'trunk_type2', 'o_trunk_type2',
-                        'egress_non_zero', 'non_zero', 'dnis_fuzzy', 'release_cause_name')
+                        'egress_non_zero', 'non_zero', 'dnis_fuzzy', 'anis_fuzzy', 'release_cause_name')
 
 
 class CdrReportDailyGetScheme(BaseModelScheme):
